unit oxFCfg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Menus;

type
  TConfigDlg = class(TForm)
    AddBtn: TButton;
    CloseBtn: TButton;
    PathListBox: TListBox;
    EditBtn: TButton;
    DelBtn: TButton;
    PopupMenu1: TPopupMenu;
    Edit1: TMenuItem;
    Delete1: TMenuItem;
    procedure PathListBoxDrawItem(Control: TWinControl; Index: Integer;
      Rect: TRect; State: TOwnerDrawState);
    procedure PathListBoxDblClick(Sender: TObject);
    procedure CloseBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure AddBtnClick(Sender: TObject);
    procedure EditBtnClick(Sender: TObject);
    procedure PathListBoxClick(Sender: TObject);
    procedure DelBtnClick(Sender: TObject);
    procedure PathListBoxMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    function FormHelp(Command: Word; Data: Integer;
      var CallHelp: Boolean): Boolean;
  private
    HelpHandled: Boolean;
  public
    Paths: TStrings;
    Procedure FillList;
    procedure WriteList;
    procedure launchPropertyDlg;
  end;

var
  ConfigDlg: TConfigDlg;

implementation
Uses OXFProp, Registry, OXReg;
{$R *.DFM}

procedure TConfigDlg.FillList;
begin
  FillPathItems(PathListBox.Items, Paths);
  PathListBoxClick(Self);
end; {FillList}

procedure TConfigDlg.WriteList;
var
  Reg: TRegistry;
  Val: Integer;
  OldValues: TStrings;
begin
  Reg := TRegistry.Create;
  try
    If Reg.OpenKey(RegKey + '\PathItems', True) then
      begin
        OldValues := TStringList.Create;
        Try {Clear out the old values}
          Reg.GetValueNames(OldValues);
          For Val := 0 to OldValues.Count -1 do
            Reg.DeleteValue(OldValues[Val]);
        finally
          OldValues.Free;
        end;
        For Val := 0 To PathListBox.Items.Count -1 do
           Reg.WriteString(PathListBox.Items[Val],Paths[Val]);
      end;
  finally
    Reg.Free;
  end;
end; {FillList}

procedure TConfigDlg.PathListBoxDrawItem(Control: TWinControl; Index: Integer;
  Rect: TRect; State: TOwnerDrawState);
begin
  With Control as TListBox do
    begin
      Canvas.FillRect(Rect);
      DrawText(Canvas.Handle, PChar(Items[Index]), Length(Items[Index]), Rect, DT_SINGLELINE);
    end;
end;

procedure TConfigDlg.PathListBoxDblClick(Sender: TObject);
begin
  If PathListBox.Itemindex > -1 then
    LaunchPropertyDlg;
  PathListBoxClick(Self);
end;

procedure TConfigDlg.launchPropertyDlg;
begin
  CFGProp := TCFGProp.Create(Self);
  With CfgProp do
    try
      PathName := PathListbox.Items[PathListBox.ItemIndex];
      Path := Paths[PathListBox.ItemIndex];
      If ShowModal = mrOK then
        begin
          Paths[PathListBox.ItemIndex] := Path;
          PathListbox.Items[PathListBox.ItemIndex] := PathName;
        end;
    finally
      Free;
      CfgProp := nil;
    end;
  PathListBoxClick(Self);
end;
procedure TConfigDlg.CloseBtnClick(Sender: TObject);
begin
  Close;
end;

procedure TConfigDlg.FormCreate(Sender: TObject);
begin
  Paths := TStringList.Create;
  FillList;
end;

procedure TConfigDlg.FormDestroy(Sender: TObject);
begin
  WriteList;
  Paths.Free;
end;

procedure TConfigDlg.AddBtnClick(Sender: TObject);
begin
  With PathListBox do
    begin
      ItemIndex := Items.Add('');
      Paths.Add('');
      LaunchPropertyDlg;
      If (Items[Items.count -1] = '') then
        begin
          ItemIndex := -1;
          Items.Delete(Items.count -1);
          Paths.Delete(Paths.count -1);
        end;
    end;
  PathListBoxClick(Self);
end;

procedure TConfigDlg.EditBtnClick(Sender: TObject);
begin
  If PathListBox.Itemindex > -1 then
    With PathListBox do
      begin
        LaunchPropertyDlg;
        If (Items[ItemIndex] = '') then
          begin
            Paths.Delete(ItemIndex);
            Items.Delete(ItemIndex);
          end;
      end;
  PathListBoxClick(Self);
end;

procedure TConfigDlg.PathListBoxClick(Sender: TObject);
var
  Selected: Boolean;
begin
  Selected := PathListBox.ItemIndex <> -1;
  EditBtn.Enabled := Selected;
  DelBtn.Enabled := Selected;
  Edit1.Enabled := Selected;
  Delete1.Enabled := Selected;
  AddBtn.Enabled := PathListBox.Items.count < MaxPaths;
end;

procedure TConfigDlg.DelBtnClick(Sender: TObject);
begin
  If PathListBox.Itemindex > -1 then
    begin
      Paths.Delete(PathListBox.ItemIndex);
      PathListBox.Items.Delete(PathListBox.ItemIndex);
    end;
  PathListBoxClick(Self)
end;

procedure TConfigDlg.PathListBoxMouseDown(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  If (Button = mbRight) and (Shift = []) then
    PathListbox.ItemIndex := PathListbox.ItemAtPos(Point(X,Y), True);
end;

procedure TConfigDlg.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  Case Key of
    VK_F1:
      Begin
        If Shift=[] then
          begin
            Application.HelpCommand(HELP_FINDER,0);
            Key := 0;
            HelpHandled := True;
          end;
      end;
  end;{Case}
end;

function TConfigDlg.FormHelp(Command: Word; Data: Integer;
  var CallHelp: Boolean): Boolean;
begin
  Result := True; {success}
  If (Command = HELP_CONTEXTPOPUP) and HelpHandled then
    begin
      CallHelp := False; {Help has been handled}
      HelpHandled := False;
    end;  
end;

end.
